#ifndef __SIRAPI_H__
#define __SIRAPI_H__

//**********************************************************************
//* SirAPI Version 1.01 (C) SIR Pty Ltd 1997-1999                      *
//*                                                                    *
//* This software is provided as is, without any explicit or           *
//* implied warranties. Use it at your own risk.                       *
//**********************************************************************

//**********************************************************************
//* This header file defines the programming interface of SirDBMS and  *
//* SirSQL dynamic link libraries. This API can be used to develop     *
//* your own front-ends for SIR database management engines.           *
//*                                                                    *
//* The system is not reenterable, so you must not call any of these   *
//* functions before the previous call is completed. Also you cannot   *
//* use both SirDBMS and SirSQL DLLs from the same application.        *
//*                                                                    *
//* To compile your calls correctly under MS-Windows macro _WIN32 must *
//* be defined. It is predefined by Visual C++. Define it in your make *
//* file for other compilers. The macro will inforce __stdcall calling *
//* convention for the DLL's export names. You should use sirdbms.lib  *
//* or sirsql.lib import library to link your application.             *
//*                                                                    *
//* Your application will use SIR's DLLs, so the SIR's home directory  *
//* must be included into your PATH (unless you place your executable  *
//* file into that directory).                                         *
//**********************************************************************

#ifndef __StdCall
#ifdef _WIN32
#define __StdCall __stdcall
#else
#define __StdCall
#endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

//*****************
//** SirDBMS API **
//*****************

int __StdCall SirDBMS_VersionNumber(void);
//
// Returns DBMS engine's version number (40000 for 4.00.00).
// It's the only function you can execute before SirDBMS_Init().
////////////////////////////////////////////////////////////////////////

int __StdCall SirDBMS_Init(
    void *hWnd,
    void (__StdCall *writeLine)(const char *text),
    void (__StdCall *writeData)(const char *text),
    const char *commandLine
);
// Must be executed before sending commands to the DBMS engine.
//
// The first argument is the system-specific handle of the main
// window. It should be the current window at this moment.
//
// DBMS engine uses the function passed as the second argument
// to write a line of text into the message buffer. User interface
// module should immediately put the text into some output window.
//
// DBMS engine uses the function passed as the third argument
// to write a line of text into the data buffer when given some
// query-type command.
//
// The engine doesn't add any end-of-line terminators, it just
// makes one call for each line of output.
//
// The last argument is a string which contains the command line
// arguments (without the leading application name).
//
// Returns TRUE on success, FALSE on failure, doesn't return if
// the command line activates the batch mode.
////////////////////////////////////////////////////////////////////////

int __StdCall SirDBMS_Exec(void *hWnd, const char *commands);
//
// Executes DBMS commands.
//
// The first argument is the system-specific handle of the current
// window. It is used as the owner of the engine's message boxes.
//
// The second argument is a DBMS command[s]. Multiple lines must be
// separated by '\n' character.
//
// Returns TRUE on success, FALSE on failure.
////////////////////////////////////////////////////////////////////////

int __StdCall SirDBMS_Stop(void *hWnd);
//
// Call this before you terminate the program.
//
// The argument is the system-specific handle of the current
// window. It is used as the owner of the engine's message boxes.
//
// This will properly disconnect and close all open files.
//
// Returns TRUE on success, FALSE on failure.
////////////////////////////////////////////////////////////////////////

int __StdCall SirDBMS_ErrorCode(void);
//
// Call this to get the error code if one of the SirDBMS_...
// functions returned FALSE. Error code 0 means that information
// is not available.
////////////////////////////////////////////////////////////////////////

//****************
//** SirSQL API **
//****************

int __StdCall SirSQL_VersionNumber(void);
//
// Returns SQL engine's version number (40000 for 4.00.00).
// It's the only function you can execute before SirSQL_Init().
////////////////////////////////////////////////////////////////////////

int __StdCall SirSQL_Init(
    void *hWnd,
    void (__StdCall *writeLine)(const char *text),
    const char *commandLine
);
// Must be executed before sending commands to the SQL engine.
//
// The first argument is the system-specific handle of the main
// window. And it should be the current window at this moment.
//
// SQL engine uses the function passed as the second argument
// to write a line of text into the output buffer. User interface
// module might immediately add the text into the output window or
// use results in some other way after it gets control back.
// The engine doesn't add any end-of-line terminators, it just
// makes one call for each line of output.
//
// The last argument is a string which contains the command line
// arguments (without the leading application name).
//
// Returns TRUE on success, FALSE on failure, doesn't return if
// the command line activates the batch mode.
////////////////////////////////////////////////////////////////////////

int __StdCall SirSQL_Exec(void *hWnd, const char *commands);
//
// Executes SQL commands.
//
// The first argument is the system-specific handle of the current
// window. It is used as the owner of the engine's message boxes.
//
// The second argument is a SQL command[s]. Multiple lines must be
// separated by '\n' character.
//
// Returns TRUE on success, FALSE on failure.
////////////////////////////////////////////////////////////////////////

int __StdCall SirSQL_Stop(void *hWnd);
//
// Call this before you terminate the program.
//
// The argument is the system-specific handle of the current
// window. It is used as the owner of the engine's message boxes.
//
// This will properly disconnect and close all open files.
//
// Returns TRUE on success, FALSE on failure.
////////////////////////////////////////////////////////////////////////

int __StdCall SirSQL_ErrorCode(void);
//
// Call this to get the error code if one of the SirSQL_...
// functions returned FALSE.
////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
}
#endif

#endif
