//**********************************************************************
//* ZTest - example of using Z-functions from C (see readme.txt)       *
//*                                                                    *
//* This software is provided as is, without any explicit or           *
//* implied warranties. Use it at your own risk.                       *
//**********************************************************************

#include <stdio.h>
#include <stdlib.h>

#include <sirzset.h>

int zRunning = 0;

void Error(int code, const char *name) {
    printf("*** Error in %s: %d\n", name, code);
    if (zRunning) {
        int dummy;
        (void)zend(&dummy);
    }
    exit(1);
}

void main(void) {

    FSTRDESC dbName = {"COMPANY ", 8};
    FSTRDESC dbPass = {"COMPANY ", 8};
    FSTRDESC hsPass = {"        ", 8};
    FSTRDESC rdPass = {"HIGH    ", 8};
    FSTRDESC wrPass = {"HIGH    ", 8};
    FSTRDESC prefix = {"./test/" , 7};
    int      prfLen = 7;

    FSTRDESC vnName = {"NAME    ", 8};
    FSTRDESC vnSal  = {"SALARY  ", 8};
    char     vdName[8];
    char     vdSal [8];

    char     enBuf[] = "                    ";
    int      enMax = sizeof(enBuf)-1;
    FSTRDESC eName;

    int      eSal;

    int      i1, i2, i3, i4;
    int      err;

    // Non-static initialization handles local address
    //
    eName.data   = enBuf;
    eName.length = enMax;

    // Start the system
    //
    i1 = 1;
    i2 = 1;
    i3 = 100000;
    i4 = 0;
    err = zstart(&i1, &i2, &i3, &i4);
    if (err < 0) Error(err, "zstart");
    zRunning = 1;

    // Attach database
    //
    i1 = 0;
    err = zordb(
        &dbName, &dbPass, &hsPass, &rdPass, &wrPass, &i1,
        &prefix, &prfLen);
    if (err < 0) Error(err, "zordb");

    // Start a "case is" level
    //
    i1 = 0;
    i2 = 1;
    err = zcis(&i1, &i2);
    if (err < 0) Error(err, "zcis");

    // Start a With key
    //
    i1 = 0;
    err = zwith(&i1);
    if (err < 0) Error(err, "zwith");

    // Put the value 1 into the Case key
    //
    i1 = 1;
    err = zintky(&i1);
    if (err < 0) Error(err, "zintky");

    // Get the case
    //
    i1 = 0;
    err = zcnext(&i1);
    if (err < 0) Error(err, "zcnext");

    // Start a "record is" level
    //
    i1 = 1;
    i2 = 0;
    i3 = 1;
    err = zris(&i1, &i2, &i3);
    if (err < 0) Error(err, "zris");
    i1 = 0;
    err = zrnext(&i1);
    if (err < 0) Error(err, "zrnext");

    // Build a descriptor for variable NAME
    //
    i1 = 1;
    i2 = 0;
    err = zdescd(vdName, &dbName, &i1, &vnName, &i2);
    if (err < 0) Error(err, "zdescd");

    // Retrieve the string value
    //
    err = zrctst(vdName, &eName, &enMax);
    if (err < 0) Error(err, "zrctst");

    // Build a descriptor for variable SALARY
    //
    i1 = 1;
    i2 = 0;
    err = zdescd(vdSal, &dbName, &i1, &vnSal, &i2);
    if (err < 0) Error(err, "zdescd");

    // Retrieve the integer value
    //
    err = zrctin(vdSal, &eSal);
    if (err < 0) Error(err, "zrctin");

    // Print results
    //
    printf("Name  : %s\n", enBuf);
    printf("Salary: %d\n", eSal);

    // End of record
    //
    i1 = 0;
    err = zrexit(&i1);
    if (err < 0) Error(err, "zrexit");

    // End of case
    //
    i1 = 0;
    err = zcexit(&i1);
    if (err < 0) Error(err, "zcexit");

    // Close the database
    //
    err = zenddb(&dbName);
    if (err < 0) Error(err, "zenddb");

    // Shut down the system
    //
    i1 = 0;
    err = zend(&i1);
    zRunning = 0;
    if (err < 0) Error(err, "zend");

    exit(0);
}
