**********************************************************************
* ZTest - example of using Z-functions from Fortran (see readme.txt) *
*                                                                    *
* This software is provided as is, without any explicit or           *
* implied warranties. Use it at your own risk.                       *
**********************************************************************

* Attention: This pragma-type include is Watcom Fortran specific.
* The file sirzset.hf in api subdirectory of Sir's home directory
* contains Watcom Fortran pragmas to define link names and calling
* convention of Z-functions.
*
*$include sirzset.hf

        subroutine Error(code, name)

            implicit none

            integer*4 code
            character*(*) name

            integer*4 zend

            common /zStatus/ zRunning
            logical*1        zRunning

            integer*4 dummy1, dummy2

            write(*,'(''*** Error in '',a,'':'',i6)') name, code

            if (zRunning) then
                zRunning = .FALSE.
                dummy1 = zend(dummy2)
            endif

            stop

        end

        program ZTest

            implicit none

            integer  *4
     &          zstart, zordb,
     &          zcis, zwith, zintky, zcnext,
     &          zris, zrnext,
     &          zdescd, zrctst, zrctin,
     &          zrexit, zcexit,
     &          zenddb, zend

            common /zStatus/ zRunning
            logical  *1      zRunning

            character*8   dbName
            character*8   dbPass
            character*8   hsPass
            character*8   rdPass
            character*8   wrPass
            character*128 prefix
            integer  *4   prfLen

            character*8   vnName
            character*8   vnSal
            real     *8   vdName
            real     *8   vdSal

            character*20  eName
            integer  *4   enLen
            integer  *4   eSal

            integer  *4   dummy
            integer  *4   err

            data dbName   /'COMPANY '/
            data dbPass   /'COMPANY '/
            data hsPass   /'        '/
            data rdPass   /'HIGH    '/
            data wrPass   /'HIGH    '/
            data prefix   /'./test/' /
            data prfLen   /7/

            data vnName   /'NAME    '/
            data vnSal    /'SALARY  '/

            data enLen    /20/

*---------- Start the system
            zRunning = .FALSE.
            err = zstart(1, 1, 100000, 0)
            if (err .lt. 0) call Error(err, 'zstart')
            zRunning = .TRUE.

*---------- Attach database
            err = zordb(
     &          dbName, dbPass, hsPass, rdPass, wrPass, 0,
     &          prefix, prfLen)
            if (err .lt. 0) call Error(err, 'zordb')

*---------- Start a "case is" level
            err = zcis(0, 1)
            if (err .lt. 0) call Error(err, 'zcis')

*---------- Start a With key
            err = zwith(0)
            if (err .lt. 0) call Error(err, 'zwith')

*---------- Put the value 1 into the Case key
            err = zintky(1)
            if (err .lt. 0) call Error(err, 'zintky')

*---------- Get the case
            err = zcnext(0)
            if (err .lt. 0) call Error(err, 'zcnext')

*---------- Start a "record is" level
            err = zris(1, 0, 1)
            if (err .lt. 0) call Error(err, 'zris')
            err = zrnext(0)
            if (err .lt. 0) call Error(err, 'zrnext')

*---------- Build a descriptor for variable NAME
            err = zdescd(vdName, dbName, 1, vnName, 0)
            if (err .lt. 0) call Error(err, 'zdescd')

*---------- Retrieve the string value
            err = zrctst(vdName, eName, enLen)
            if (err .lt. 0) call Error(err, 'zrctst')

*---------- Build a descriptor for variable SALARY
            err = zdescd(vdSal, dbName, 1, vnSal, 0)
            if (err .lt. 0) call Error(err, 'zdescd')

*---------- Retrieve the integer value
            err = zrctin(vdSal, eSal)
            if (err .lt. 0) call Error(err, 'zrctin')

*---------- Print results
            write(*,'(''Name  : '',a )') eName
            write(*,'(''Salary: '',i4)') eSal

*---------- End of record
            err = zrexit(0)
            if (err .lt. 0) call Error(err, 'zrexit')

*---------- End of case
            err = zcexit(0)
            if (err .lt. 0) call Error(err, 'zcexit')

*---------- Close the database
            err = zenddb(dbName)
            if (err .lt. 0) call Error(err, 'zenddb')

*---------- Shut down the system
            err = zend(dummy)
            zRunning = .FALSE.
            if (err .lt. 0) call Error(err, 'zend')

        end
